use serde::{Deserialize, Serialize};
use sea_orm::entity::prelude::*;


// Model是只读的，只能用来SELECT
#[derive(Debug, Clone, PartialEq, DeriveEntityModel, Serialize, Deserialize)]
#[sea_orm(table_name = "categoies")]
pub struct Model {
    #[sea_orm(primary_key)]
    #[serde(skip_deserializing)]
    pub id: u32,
    pub name: String,
    pub is_del: bool,
}

#[derive(Debug, Clone, Copy, EnumIter)]
pub enum Relation {
    Articles,
}

impl RelationTrait for Relation {
    fn def(&self) -> RelationDef {
       Entity::has_many(super::article::Entity).into()
    }
}

impl Related<super::article::Entity> for Entity {
    fn to() -> RelationDef {
        Relation::Articles.def()
    }
}


// INSERT/UPDATE/DELETE 等属于写操作，需使用 ActiveModel。
/// [DeriveEntityModel] 这个 derive 根据我们定义的[Model]，生成了包括 [ActiveModel]在内的多个数据结构
impl ActiveModelBehavior for ActiveModel {}