use askama::Template;
use axum::http::{header, HeaderMap, StatusCode};
use axum::response::Html;
use sea_orm::DatabaseConnection;

pub use index::index;

use crate::err::AppError;
use crate::Result;
use crate::state::AppState;

pub mod category;
mod index;
pub mod article;

fn get_conn(state: &AppState) -> &DatabaseConnection {
    &state.conn
}

type HtmlResponse = Html<String>;
type RedirectResponse = (StatusCode, HeaderMap, ());

/// 渲染模板
fn render<T: Template>(tpl: T, handler_name: &str) -> Result<HtmlResponse> {
    let out = tpl
        .render()
        .map_err(AppError::from)
        .map_err(log_error(handler_name))?;
    Ok(Html(out))
}

/// 记录错误
fn log_error(handler_name: &str) -> Box<dyn Fn(AppError) -> AppError> {
    let handler_name = handler_name.to_string();
    Box::new(move |err| {
        tracing::error!("{}: {:?}", handler_name, err);
        err
    })
}

fn redirect(url: &str) -> Result<RedirectResponse> {
    let mut header = HeaderMap::new();
    header.insert(header::LOCATION, url.parse().unwrap());
    Ok((StatusCode::FOUND, header, ()))
}