use serde::Deserialize;

const DEFAULT_PAGE_SIZE: u64 = 15;

#[derive(Debug, Clone, Deserialize)]
pub struct CategoryParams {
    // 用于搜索的关键字
    pub keyword: Option<String>,
    // 是否删除
    pub is_del: Option<i32>,
    // 排序
    pub sort: Option<String>,
    // 每页记录条数
    pub page_size: Option<u64>,
    // 当前页码
    pub page: Option<u64>,

    pub msg: Option<String>,
}

impl Default for CategoryParams {
    fn default() -> Self {
        Self {
            keyword: None,
            is_del: None,
            sort: None,
            page_size: None,
            page: None,
            msg: None,
        }
    }
}

impl CategoryParams {
    pub fn keyword(&self) -> String {
        self.keyword.clone().unwrap_or("".to_string())
    }
    pub fn keyword_opt(&self) -> Option<String> {
        match &self.keyword {
            Some(s) => {
                if s.is_empty() {
                    None
                } else {
                    Some(s.to_string())
                }
            }
            _ => None,
        }
    }

    pub fn is_del_opt(&self) -> Option<bool> {
        match self.is_del {
            Some(n) => match n {
                0 => Some(false),
                1 => Some(true),
                _ => None,
            },
            _ => None,
        }
    }

    pub fn is_del(&self) -> i32 {
        match self.is_del_opt() {
            Some(b) => {
                if b {
                    1
                } else {
                    0
                }
            }
            _ => -1,
        }
    }

    pub fn sort(&self) -> String {
        self.sort.clone().unwrap_or("".to_string())
    }
    pub fn order(&self) -> Option<sea_orm::Order> {
        match self.sort().as_str() {
            "asc" => Some(sea_orm::Order::Asc),
            "desc" => Some(sea_orm::Order::Desc),
            _ => None,
        }
    }
    pub fn page_size(&self) -> u64 {
        let ps = self.page_size.unwrap_or(0);
        if ps <= 0 {
            return DEFAULT_PAGE_SIZE;
        }
        ps
    }
    pub fn page(&self) -> u64 {
        self.page.unwrap_or(0)
    }
}

#[derive(Deserialize, Debug)]
pub struct DelParams {
    pub id: u32,
    pub real: Option<bool>,
}

pub type ArticleParams = CategoryParams;
